@@ -22,6 +22,7 @@
 */
 
 #include <config.h>
+#include <glib/gi18n.h>
 #include "htmlcolor.h"
 #include "htmlcolorset.h"
 #include "htmlengine-save.h"
@@ -81,7 +82,7 @@ fit_line (HTMLObject *o,
 {
 	if (!start_of_line)
 		return HTML_FIT_NONE;
-	o->width = width_left;
+	o->width = MIN (width_left, o->max_width);
 
 	if (o->percent == 0) {
 		gint pixel_size = html_painter_get_pixel_size (painter);
@@ -148,7 +149,7 @@ html_rule_draw (HTMLObject *o,
 	HTMLEngine *e;
 
 	if (p->widget && GTK_IS_HTML (p->widget))
-		e = GTK_HTML (p->widget)->engine;
+		e = html_object_engine (o, GTK_HTML (p->widget)->engine);
 	else
 		return;
 
@@ -184,9 +185,9 @@ html_rule_draw (HTMLObject *o,
 	}
 
 	if (rule->shade)
-		html_painter_draw_panel (p,
-					 &((html_colorset_get_color (e->settings->color_set, HTMLBgColor))->color),
-					 xp, yp, w, h, GTK_HTML_ETCH_IN, 1);
+		html_painter_draw_border (p,
+					  &((html_colorset_get_color (e->settings->color_set, HTMLBgColor))->color),
+					  xp, yp, w, h, HTML_BORDER_INSET, 1);
 	else {
 		html_painter_set_pen (p, &html_colorset_get_color_allocated (e->settings->color_set, p,
 									     HTMLTextColor)->color);
